summaryrefslogtreecommitdiffstats
path: root/src/viewcontainer.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /src/viewcontainer.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/viewcontainer.h')
-rw-r--r--src/viewcontainer.h62
1 files changed, 32 insertions, 30 deletions
diff --git a/src/viewcontainer.h b/src/viewcontainer.h
index c798530..25f0f33 100644
--- a/src/viewcontainer.h
+++ b/src/viewcontainer.h
@@ -11,10 +11,10 @@
#ifndef VIEWCONTAINER_H
#define VIEWCONTAINER_H
-#include <qdragobject.h>
-#include <qmap.h>
-#include <qsplitter.h>
-#include <qvaluelist.h>
+#include <tqdragobject.h>
+#include <tqmap.h>
+#include <tqsplitter.h>
+#include <tqvaluelist.h>
class KTechlab;
class View;
@@ -22,14 +22,14 @@ class ViewArea;
class ViewContainer;
class KConfig;
-class QHBoxLayout;
-class QLayout;
-class QSplitter;
+class TQHBoxLayout;
+class TQLayout;
+class TQSplitter;
-typedef QMap< uint, ViewArea* > ViewAreaMap;
-typedef QValueList<int> IntList;
+typedef TQMap< uint, ViewArea* > ViewAreaMap;
+typedef TQValueList<int> IntList;
-class ViewContainerDrag : public QStoredDrag
+class ViewContainerDrag : public TQStoredDrag
{
public:
ViewContainerDrag( ViewContainer *viewContainer );
@@ -42,14 +42,15 @@ protected:
/**
-Contains either exactly one View, or two ViewAreas, seperated by a QSplitter.
+Contains either exactly one View, or two ViewAreas, seperated by a TQSplitter.
If it contains one view, then the value returned in id() is that of the view.
If it contains two ViewAreas, then the value returned by id() is -1.
@author David Saxton
*/
-class ViewArea : public QSplitter
+class ViewArea : public TQSplitter
{
Q_OBJECT
+ TQ_OBJECT
public:
enum Position
{
@@ -57,7 +58,7 @@ public:
Bottom
};
- ViewArea( QWidget *parent, ViewContainer *viewContainer, int id, const char *name = 0 );
+ ViewArea( TQWidget *tqparent, ViewContainer *viewContainer, int id, const char *name = 0 );
~ViewArea();
ViewContainer *viewContainer() const { return p_viewContainer; }
@@ -67,7 +68,7 @@ public:
*/
ViewArea *createViewArea( Position position, uint id );
/**
* Adds the given View to the main part of the layout
*/
void setView( View *view );
/**
@@ -78,10 +79,10 @@ public:
* Restores the state of this ViewArea and any contained ViewAreas
* @param groupName e.g. "ViewContainer 1"
*/
- void restoreState( KConfig *config, int id, const QString &groupName );
+ void restoreState( KConfig *config, int id, const TQString &groupName );
/**
* Returns true if this ViewArea can save useful information as to its state
- * (i.e. it's children can save useful information about their state, or has
+ * (i.e. it's tqchildren can save useful information about their state, or has
* a view with a url in it)
*/
bool canSaveUsefulStateInfo() const;
@@ -90,17 +91,17 @@ public:
*/
void setKTechlabDeleted();
- static QString fileKey( int id );
- static QString containsKey( int id );
- static QString orientationKey( int id );
+ static TQString fileKey( int id );
+ static TQString containsKey( int id );
+ static TQString orientationKey( int id );
protected slots:
- void viewAreaDestroyed( QObject *obj );
+ void viewAreaDestroyed( TQObject *obj );
void viewDestroyed();
protected:
int m_id;
- QGuardedPtr<View> p_view;
+ TQGuardedPtr<View> p_view;
ViewArea *p_viewArea1;
ViewArea *p_viewArea2;
ViewContainer *p_viewContainer;
@@ -109,16 +110,17 @@ protected:
/**
@author David Saxton
*/
-class ViewContainer : public QWidget
+class ViewContainer : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a new ViewContainer, along with a default ViewArea ready for
* parenting a View, with an id of 0. parent is only used if ktechlab is
* null; otherwise the parent widget is ktechlab's tabWidget()
*/
- ViewContainer( const QString & caption, KTechlab * ktechlab, QWidget * parent = 0 );
+ ViewContainer( const TQString & caption, KTechlab * ktechlab, TQWidget * tqparent = 0 );
~ViewContainer();
/**
@@ -147,7 +149,7 @@ public:
*/
bool closeViewArea( uint id );
/**
* Creates a view area (parent QWidget, splitter et al) ready for inclusion
* of a view.
* @param relativeViewArea the viewarea to position the new viewarea next to, if -1 then is taken to be the active view area
* @param position Top, Right, Bottom or Left of given relativeViewArea
@@ -195,7 +197,7 @@ public:
*/
void setIdUsed( int id );
/**
* Writes the state of the View Container (layout of views and view URLs)
* to the given KConfig. Doesn't change the group - so preset it if
* needed!
*/
@@ -205,7 +207,7 @@ public:
* the ViewContainer with all appropriate views open
* @param groupName e.g. "ViewContainer 1"
*/
- void restoreState( KConfig *config, const QString &groupName );
+ void restoreState( KConfig *config, const TQString &groupName );
/**
* Returns a unique id (negative) for a ViewArea that is now a Parent of other ViewAreas
*/
@@ -216,7 +218,7 @@ public:
int uniqueNewId();
/**
* Returns true if this ViewArea can save useful information as to its state
- * (i.e. it's children can save useful information about their state, or has
+ * (i.e. it's tqchildren can save useful information about their state, or has
* a view with a url in it)
*/
bool canSaveUsefulStateInfo() const;
@@ -232,7 +234,7 @@ public slots:
void updateCaption();
protected slots:
- void baseViewAreaDestroyed( QObject *obj );
+ void baseViewAreaDestroyed( TQObject *obj );
protected:
void restoreViewArea( KConfig *config, int id, ViewArea *viewArea );
@@ -67,7 +68,7 @@ public:
ViewArea *createViewArea( Position position, uint id );
/**
- * Adds the given View to the main part of the layout
+ * Adds the given View to the main part of the tqlayout
*/
void setView( View *view );
@@ -109,16 +110,17 @@ protected:
/**
* Constructs a new ViewContainer, along with a default ViewArea ready for
- * parenting a View, with an id of 0. parent is only used if ktechlab is
- * null; otherwise the parent widget is ktechlab's tabWidget()
+ * tqparenting a View, with an id of 0. tqparent is only used if ktechlab is
+ * null; otherwise the tqparent widget is ktechlab's tabWidget()
*/
@@ -147,7 +149,7 @@ public:
bool closeViewArea( uint id );
/**
- * Creates a view area (parent QWidget, splitter et al) ready for inclusion
+ * Creates a view area (tqparent TQWidget, splitter et al) ready for inclusion
* of a view.
* @param relativeViewArea the viewarea to position the new viewarea next to, if -1 then is taken to be the active view area
@@ -195,7 +197,7 @@ public:
void setIdUsed( int id );
/**
- * Writes the state of the View Container (layout of views and view URLs)
+ * Writes the state of the View Container (tqlayout of views and view URLs)
* to the given KConfig. Doesn't change the group - so preset it if
* needed!